@@ -4,7 +4,7 @@ from ihm import AsymUnitRange, _remove_identical  # noqa: F401
 import modelcif.data
 import sys
 
-__version__ = '0.4'
+__version__ = '0.5'
 
 
 class System(object):
@@ -110,10 +110,10 @@ class System(object):
             self._all_template_transformations()))
         self.target_entities = list(_remove_identical(
             self._all_target_entities()))
-        self.data = list(_remove_identical(
-            self._all_data()))
         self.data_groups = list(_remove_identical(
             self._all_data_groups()))
+        self.data = list(_remove_identical(
+            self._all_data()))
         self.model_groups = list(_remove_identical(self.model_groups))
         self.software_groups = list(_remove_identical(
             self._all_software_groups()))
@@ -205,12 +205,18 @@ class System(object):
         return self.model_groups
 
     def _all_data(self):
+        def _all_data_in_groups():
+            for dg in self.data_groups:
+                if isinstance(dg, list):
+                    for data in dg:
+                        yield data
         return itertools.chain(
             self.data,
             self.templates,
             self.target_entities,
             self.alignments,
-            (model for group, model in self._all_models()))
+            (model for group, model in self._all_models()),
+            _all_data_in_groups())
 
     def _all_data_groups(self):
         """Return all DataGroup (or singleton Data) objects"""
@@ -342,7 +348,8 @@ class SoftwareParameter(object):
 
        :param str name: A short name for this parameter.
        :param value: Parameter value.
-       :type value: ``int``, ``float``, ``str``, or ``bool``
+       :type value: ``int``, ``float``, ``str``, ``bool``, list of ``int``,
+             or list of ``float``.
        :param str description: A longer description of the parameter.
     """
     def __init__(self, name, value, description=None):
@@ -487,3 +494,27 @@ class NonPolymerFromTemplate(AsymUnit):
             template.entity, details=details, auth_seq_id_map=auth_seq_id_map,
             id=id, strand_id=strand_id)
         self.template, self.explicit = template, explicit
+
+
+class ReferenceDatabase(modelcif.data.Data):
+    """A reference database used in the modeling. This is typically a
+       sequence database used for template search, alignments, etc.
+       These objects are passed as input or output to
+       :class:`modelcif.protocol.Step`. See also :class:`modelcif.data.Data`
+       for more details.
+
+       Compare with :class:`modelcif.reference.TargetReference`, which pertains
+       to just the modeled sequence itself; this class describes *multiple*
+       sequences.
+
+       :param str name: Name of the database.
+       :param str url: Location of the database.
+       :param str version: Version of the database.
+       :param release_date: Release date of the specified version.
+       :type release_date: :class:`datetime.date`
+    """
+    data_content_type = "reference database"
+
+    def __init__(self, name, url, version=None, release_date=None):
+        super(ReferenceDatabase, self).__init__(name)
+        self.url, self.version, self.release_date = url, version, release_date
