@@ -13,15 +13,15 @@ import modelcif.data
 
 
 class _AuditConformDumper(Dumper):
-    URL = ("https://raw.githubusercontent.com/" +
-           "ihmwg/ModelCIF/%s/mmcif_ma.dic")
+    URL = ("https://raw.githubusercontent.com/ihmwg/ModelCIF/%s/base/" +
+           "mmcif_ma-core.dic")
 
     def dump(self, system, writer):
         with writer.category("_audit_conform") as lp:
             # Update to match the version of the ModelCIF dictionary
             # we support:
-            lp.write(dict_name="mmcif_ma.dic", dict_version="1.3.8",
-                     dict_location=self.URL % "0975b79")
+            lp.write(dict_name="mmcif_ma.dic", dict_version="1.4.0",
+                     dict_location=self.URL % "a24fcfa")
 
 
 class _EntryLinkDumper(Dumper):
@@ -180,6 +180,18 @@ class _SoftwareGroupDumper(Dumper):
                                  group_id=g._group_id, software_id=s._id,
                                  parameter_group_id=param)
 
+    def _handle_list(self, value):
+        list_type_map = {int: 'integer-csv', float: 'float-csv'}
+        types = frozenset(type(x) for x in value)
+        if types == frozenset((int,)):
+            data_type = list_type_map[int]
+        elif types == frozenset((float,)) or types == frozenset((int, float)):
+            # Treat mix of int and float as float
+            data_type = list_type_map[float]
+        else:
+            raise TypeError("Only lists of ints or floats are supported")
+        return data_type, ",".join(str(x) for x in value)
+
     def dump_parameters(self, system, writer):
         parameter_id = itertools.count(1)
         type_map = {int: "integer", float: "float", str: "string",
@@ -191,10 +203,14 @@ class _SoftwareGroupDumper(Dumper):
             for g in self._param_groups:
                 group_id = self._param_group_id[id(g)]
                 for p in g:
+                    if isinstance(p.value, (list, tuple)):
+                        data_type, value = self._handle_list(p.value)
+                    else:
+                        data_type = type_map.get(type(p.value), str)
+                        value = p.value
                     lp.write(parameter_id=next(parameter_id),
-                             group_id=group_id,
-                             data_type=type_map.get(type(p.value), str),
-                             name=p.name, value=p.value,
+                             group_id=group_id, data_type=data_type,
+                             name=p.name, value=value,
                              description=p.description)
 
 
@@ -245,6 +261,21 @@ class _DataGroupDumper(Dumper):
                                  group_id=g._data_group_id, data_id=d._data_id)
 
 
+class _DataRefDBDumper(Dumper):
+    def dump(self, system, writer):
+        with writer.loop(
+                "_ma_data_ref_db",
+                ["data_id", "name", "location_url",
+                 "version", "release_date"]) as lp:
+            for d in system.data:
+                if not isinstance(d, modelcif.ReferenceDatabase):
+                    continue
+                lp.write(data_id=d._data_id, name=d.name, location_url=d.url,
+                         version=d.version,
+                         release_date=date.isoformat(d.release_date)
+                         if d.release_date else None)
+
+
 class _AssemblyDumper(Dumper):
     def finalize(self, system):
         for n, asmb in enumerate(system.assemblies):
@@ -760,7 +791,8 @@ class ModelCIFVariant(Variant):
         ihm.dumper._EntityPolyDumper, _EntityNonPolyDumper,
         ihm.dumper._EntityPolySeqDumper, ihm.dumper._StructAsymDumper,
         ihm.dumper._PolySeqSchemeDumper, ihm.dumper._NonPolySchemeDumper,
-        _DataDumper, _DataGroupDumper, _TargetEntityDumper, _AssemblyDumper,
+        _DataDumper, _DataGroupDumper, _DataRefDBDumper,
+        _TargetEntityDumper, _AssemblyDumper,
         _TemplateTransformDumper, _AlignmentDumper,
         _ProtocolDumper, _ModelDumper, _AssociatedDumper, _QAMetricDumper]
 
