@@ -20,6 +20,15 @@ import collections
 import functools
 
 
+def _get_date(iso_date_str):
+    """Get a datetime.date obj for a string in isoformat."""
+    if iso_date_str is None:
+        return None
+    return date(int(iso_date_str[0:4]),
+                int(iso_date_str[5:7]),
+                int(iso_date_str[8:10]))
+
+
 class _AuditConformHandler(Handler):
     category = '_audit_conform'
 
@@ -122,6 +131,16 @@ class _SystemReader(object):
         for e in self.system.entities:
             e.sequence = tuple(e.sequence)
 
+        # If no Assembly is provided, assume each model consists of all Asyms
+        # Assume everything in every Model is atomic
+        for mg in self.system.model_groups:
+            for m in mg:
+                if not m.assembly:
+                    m.assembly.extend(self.system.asym_units[:])
+                m.representation = ihm.representation.Representation(
+                    [ihm.representation.AtomicSegment(seg, rigid=False)
+                     for seg in m.assembly])
+
 
 class _DatabaseHandler(Handler):
     category = '_database_2'
@@ -203,9 +222,17 @@ class _SoftwareGroupHandler(Handler):
 class _SoftwareParameterHandler(Handler):
     category = '_ma_software_parameter'
 
+    def _get_int_list(self, value):
+        return [int(x) for x in value.split(',')]
+
+    def _get_float_list(self, value):
+        return [float(x) for x in value.split(',')]
+
     def __call__(self, group_id, data_type, name, value, description):
         type_map = {"integer": self.get_int, "float": self.get_float,
-                    "boolean": self.get_bool, "string": str}
+                    "boolean": self.get_bool, "string": str,
+                    "integer-csv": self._get_int_list,
+                    "float-csv": self._get_float_list}
         pg = self.sysr.software_parameters[group_id]
         converter = type_map.get(data_type, str)
         p = modelcif.SoftwareParameter(name=name, value=converter(value),
@@ -247,6 +274,17 @@ class _DataGroupHandler(Handler):
         g.append(data_id)
 
 
+class _DataRefDBHandler(Handler):
+    category = '_ma_data_ref_db'
+
+    def __call__(self, data_id, name, location_url, version, release_date):
+        d = modelcif.ReferenceDatabase(
+            name=name, url=location_url, version=version,
+            release_date=_get_date(release_date))
+        self.sysr.data_by_id[data_id] = d
+        d._data_id = data_id
+
+
 class _EnumerationMapper(object):
     """Map an mmCIF enumerated value to the corresponding Python class"""
     def __init__(self, module, base_class, attr="name"):
@@ -302,14 +340,6 @@ class _TargetRefDBHandler(Handler):
         self.type_map = _EnumerationMapper(modelcif.reference,
                                            modelcif.reference.TargetReference)
 
-    def get_date(self, iso_date_str):
-        """Get a datetime.date obj for a string in isoformat."""
-        if iso_date_str is None:
-            return None
-        return date(int(iso_date_str[0:4]),
-                    int(iso_date_str[5:7]),
-                    int(iso_date_str[8:10]))
-
     def __call__(self, target_entity_id, db_name, db_name_other_details,
                  db_code, db_accession, seq_db_isoform, seq_db_align_begin,
                  seq_db_align_end, ncbi_taxonomy_id, organism_scientific,
@@ -321,7 +351,7 @@ class _TargetRefDBHandler(Handler):
                   align_end=self.get_int(seq_db_align_end),
                   isoform=seq_db_isoform, ncbi_taxonomy_id=ncbi_taxonomy_id,
                   organism_scientific=organism_scientific,
-                  sequence_version_date=self.get_date(
+                  sequence_version_date=_get_date(
                       seq_db_sequence_version_date),
                   sequence_crc64=seq_db_sequence_checksum)
         e.references.append(ref)
@@ -790,7 +820,8 @@ class ModelCIFVariant(Variant):
         ihm.reader._EntityPolySeqHandler, _EntityNonPolyHandler,
         ihm.reader._StructAsymHandler, _SoftwareGroupHandler,
         _DatabaseHandler, _SoftwareParameterHandler,
-        _DataHandler, _DataGroupHandler, _TargetEntityHandler,
+        _DataHandler, _DataGroupHandler, _DataRefDBHandler,
+        _TargetEntityHandler,
         _TargetRefDBHandler, _TransformationHandler, _TemplateDetailsHandler,
         _TemplateRefDBHandler, _TemplatePolySegmentHandler,
         _TemplatePolyHandler, _TemplateNonPolyHandler,
